@@ -11,7 +11,7 @@ use HTML::Parser 3.08;
 require 5.005;
 
 use vars qw($VERSION @ISA);
-$VERSION = '0.13';
+$VERSION = '0.15';
 @ISA = qw(HTML::Parser);
 
 sub new {
@@ -92,6 +92,8 @@ sub start {
 	$attr->{'value'} = $self->escapeHTML($value);
       } elsif (lc $attr->{'type'} eq 'radio'){
 	$value = $value->[0] if ref($value) eq 'ARRAY';
+	# value for radio boxes default to 'on', works with netscape
+	$attr->{'value'} = 'on' unless exists $attr->{'value'};
 	if ($attr->{'value'} eq $value){
 	  $attr->{'checked'} = '__BOOLEAN__';
 	} else {
@@ -102,6 +104,9 @@ sub start {
 	  $value = [ $value ];
 	}
 
+	# value for checkboxes default to 'on', works with netscape
+	$attr->{'value'} = 'on' unless exists $attr->{'value'};
+
 	delete $attr->{'checked'}; # Everything is unchecked to start
 
 	foreach my $v ( @$value ) {
@@ -351,7 +356,7 @@ L<HTML::Parser>
 
 =head1 VERSION
 
-This documentation describes HTML::FillInForm module version 0.13.
+This documentation describes HTML::FillInForm module version 0.15.
 
 =head1 SECURITY
 
@@ -398,5 +403,6 @@ Fixes, Bug Reports, Docs have been generously provided by:
   Mark Stosberg
   Paul Lindner
   Joseph Yanni
+  Philip Mak
 
 Thanks!
